@@ -1,3 +1,5 @@
+# -*- encoding: utf-8 -*-
+#
 # Copyright (C) 2006, 2007 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
@@ -26,15 +28,27 @@ from bzrlib import (
     errors,
     osutils,
     repository,
+    tests,
     urlutils,
     upgrade,
     )
-from bzrlib.osutils import format_date
-from bzrlib.tests import TestSkipped
-from bzrlib.tests.blackbox import ExternalBase
+from bzrlib.tests import blackbox
 
 
-class TestInfoXml(ExternalBase):
+class TestInfoXml(blackbox.ExternalBase):
+
+    def test_should_normalize_non_ascii_url(self):
+        root = '/C:' if sys.platform == 'win32' else ''
+        url = u'file://%s/Maçã/does/not/exist' % root
+        out, err = self.run_bzr(['xmlinfo', url], retcode=3)
+        from bzrlib.urlutils import normalize_url
+        nurl = normalize_url(url)
+        self.assertEqual(
+            '<?xml version="1.0" encoding="%s"?>'
+            '<error><class>NotBranchError</class><dict><key>path</key>'
+            '<value>%s/</value></dict><message>Not a branch: "%s/".</message>'
+            '</error>' % (osutils.get_user_encoding(), nurl, nurl), err)
+
 
     def test_info_non_existing(self):
         if sys.platform == "win32":
@@ -46,7 +60,8 @@ class TestInfoXml(ExternalBase):
         self.assertEqual('<?xml version="1.0" encoding="%s"?><error>'
                 '<class>NotBranchError</class><dict><key>path</key><value>'
                 '%s</value></dict><message>Not a branch: "%s".</message>'
-                '</error>' % (bzrlib.user_encoding, location, location), err)
+                '</error>' % (osutils.get_user_encoding(),
+                              location, location), err)
 
     def test_info_standalone(self):
         transport = self.get_transport()
@@ -113,7 +128,7 @@ class TestInfoXml(ExternalBase):
         self.assertEqual('', err)
         tree1.commit('commit one')
         rev = branch1.repository.get_revision(branch1.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
 
         # Branch standalone with push location
         branch2 = branch1.bzrdir.sprout('branch').open_branch()
@@ -295,21 +310,14 @@ class TestInfoXml(ExternalBase):
 <info>
 <layout>Lightweight checkout</layout>
 <formats>
-<format>1.6</format>
-<format>1.6.1-rich-root</format>
-<format>1.9</format>
-<format>1.9-rich-root</format>
-<format>dirstate</format>
-<format>dirstate-tags</format>
-<format>pack-0.92</format>
-<format>rich-root</format>
-<format>rich-root-pack</format>
+<format>2a</format>
+<format>development-subtree</format>
 </formats>
 <location>
 <light_checkout_root>lightcheckout</light_checkout_root><checkout_of_branch>standalone</checkout_of_branch></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>Branch format 4</branch>
 <repository>Weave repository format 6</repository>
 </format>
@@ -345,7 +353,7 @@ class TestInfoXml(ExternalBase):
         tree1.add('b')
         tree1.commit('commit two')
         rev = branch1.repository.get_revision(branch1.revision_history()[-1])
-        datestring_last = format_date(rev.timestamp, rev.timezone)
+        datestring_last = osutils.format_date(rev.timestamp, rev.timezone)
 
         # Out of date branched standalone branch will not be detected
         out, err = self.run_bzr('xmlinfo -v branch')
@@ -496,21 +504,14 @@ class TestInfoXml(ExternalBase):
 <info>
 <layout>Lightweight checkout</layout>
 <formats>
-<format>1.6</format>
-<format>1.6.1-rich-root</format>
-<format>1.9</format>
-<format>1.9-rich-root</format>
-<format>dirstate</format>
-<format>dirstate-tags</format>
-<format>pack-0.92</format>
-<format>rich-root</format>
-<format>rich-root-pack</format>
+<format>2a</format>
+<format>development-subtree</format>
 </formats>
 <location>
 <light_checkout_root>lightcheckout</light_checkout_root><checkout_of_branch>standalone</checkout_of_branch></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>Branch format 4</branch>
 <repository>Weave repository format 6</repository>
 </format>
@@ -552,7 +553,7 @@ class TestInfoXml(ExternalBase):
 <info>
 <layout>Standalone branch</layout>
 <formats>
-<format>pack-0.92</format>
+<format>2a</format>
 </formats>
 <location>
 <branch_root>branch</branch_root></location>
@@ -664,27 +665,20 @@ class TestInfoXml(ExternalBase):
         tree2.add('a')
         tree2.commit('commit one')
         rev = repo.get_revision(branch2.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('xmlinfo tree/lightcheckout --verbose')
         expected_xml = '''<?xml version="1.0"?>
 <info>
 <layout>Lightweight checkout</layout>
 <formats>
-<format>1.6</format>
-<format>1.6.1-rich-root</format>
-<format>1.9</format>
-<format>1.9-rich-root</format>
-<format>dirstate</format>
-<format>dirstate-tags</format>
-<format>pack-0.92</format>
-<format>rich-root</format>
-<format>rich-root-pack</format>
+<format>2a</format>
+<format>development-subtree</format>
 </formats>
 <location>
 <light_checkout_root>tree/lightcheckout</light_checkout_root><checkout_of_branch>repo/branch</checkout_of_branch><shared_repository>repo</shared_repository></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>%s</branch>
 <repository>%s</repository>
 </format>
@@ -724,13 +718,13 @@ class TestInfoXml(ExternalBase):
 <info>
 <layout>Checkout</layout>
 <formats>
-<format>dirstate</format>
+<format>unnamed</format>
 </formats>
 <location>
 <checkout_root>tree/checkout</checkout_root><checkout_of_branch>repo/branch</checkout_of_branch></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>%s</branch>
 <repository>%s</repository>
 </format>
@@ -772,13 +766,13 @@ class TestInfoXml(ExternalBase):
 <info>
 <layout>Checkout</layout>
 <formats>
-<format>dirstate</format>
+<format>unnamed</format>
 </formats>
 <location>
 <checkout_root>tree/checkout</checkout_root><checkout_of_branch>repo/branch</checkout_of_branch></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>%s</branch>
 <repository>%s</repository>
 </format>
@@ -815,27 +809,20 @@ class TestInfoXml(ExternalBase):
 
         # Out of date lightweight checkout
         rev = repo.get_revision(branch1.revision_history()[-1])
-        datestring_last = format_date(rev.timestamp, rev.timezone)
+        datestring_last = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('xmlinfo tree/lightcheckout --verbose')
         expected_xml = '''<?xml version="1.0"?>
 <info>
 <layout>Lightweight checkout</layout>
 <formats>
-<format>1.6</format>
-<format>1.6.1-rich-root</format>
-<format>1.9</format>
-<format>1.9-rich-root</format>
-<format>dirstate</format>
-<format>dirstate-tags</format>
-<format>pack-0.92</format>
-<format>rich-root</format>
-<format>rich-root-pack</format>
+<format>2a</format>
+<format>development-subtree</format>
 </formats>
 <location>
 <light_checkout_root>tree/lightcheckout</light_checkout_root><checkout_of_branch>repo/branch</checkout_of_branch><shared_repository>repo</shared_repository></location>
 <format>
 <control>Meta directory format 1</control>
-<working_tree>Working tree format 4</working_tree>
+<working_tree>Working tree format 6</working_tree>
 <branch>%s</branch>
 <repository>%s</repository>
 </format>
@@ -1020,7 +1007,7 @@ class TestInfoXml(ExternalBase):
         tree1.add('a')
         tree1.commit('commit one')
         rev = repo.get_revision(branch1.revision_history()[0])
-        datestring_first = format_date(rev.timestamp, rev.timezone)
+        datestring_first = osutils.format_date(rev.timestamp, rev.timezone)
         out, err = self.run_bzr('xmlinfo -v repo/branch1')
         expected_xml = '''<?xml version="1.0"?>
 <info>
@@ -1311,16 +1298,9 @@ class TestInfoXml(ExternalBase):
             (False, True): 'Lightweight checkout',
             (False, False): 'Checkout',
             }[(shared_repo is not None, light_checkout)]
-        format = {True: '<format>1.6</format>\n' +
-                        '<format>1.6.1-rich-root</format>\n' +
-                        '<format>1.9</format>\n'+
-                        '<format>1.9-rich-root</format>\n'+
-                        '<format>dirstate</format>\n' +
-                        '<format>dirstate-tags</format>\n' +
-                        '<format>pack-0.92</format>\n' +
-                        '<format>rich-root</format>\n' +
-                        '<format>rich-root-pack</format>',
-                  False: '<format>dirstate</format>'}[light_checkout]
+        format = {True: '<format>2a</format>\n' +
+                        '<format>development-subtree</format>\n',
+                  False: '<format>unnamed</format>'}[light_checkout]
         if repo_locked:
             repo_locked = lco_tree.branch.repository.get_physical_lock_status()
         if repo_locked or branch_locked or tree_locked:
@@ -1528,7 +1508,7 @@ class TestInfoXml(ExternalBase):
 
     def test_info_locking_oslocks(self):
         if sys.platform == "win32":
-            raise TestSkipped("don't use oslocks on win32 in unix manner")
+            raise tests.TestSkipped("don't use oslocks on win32 in unix manner")
 
         tree = self.make_branch_and_tree('branch',
                                          format=bzrlib.bzrdir.BzrDirFormat6())
