@@ -1,5 +1,5 @@
 # Copyright (C) 2005, 2006, 2007, 2008, 2009 Canonical Ltd
-# Copyright (C) 2008, 2009 Guillermo Gonzalez 
+# Copyright (C) 2008, 2009 Guillermo Gonzalez
 # -*- coding: utf-8 -*-
 #
 # This program is free software; you can redistribute it and/or modify
@@ -133,7 +133,7 @@ class TestLog(ExternalBase):
         #    '</dict><message>Start revision must be older than the end '
         #    'revision.</message></error>',),
         self.run_bzr_error(('Start revision must be older than '
-            'the end revision.'),
+            'the end revision.',),
                            ['xmllog', '-r3..1'])
 
     def test_log_revno_n_path(self):
@@ -157,8 +157,9 @@ class TestLog(ExternalBase):
         # should give an error
         wt = self.make_branch_and_tree('.')
         out, err = self.run_bzr('xmllog does-not-exist', retcode=3)
-        self.assertContainsRe(err, 
-                'Path unknown at end or start of revision range: does-not-exist')
+        self.assertContainsRe(
+            err,
+            'Path unknown at end or start of revision range: does-not-exist')
 
     def test_log_with_tags(self):
         tree = self._prepare(format='dirstate-tags')
@@ -440,7 +441,7 @@ class TestLogNestedMerges(ExternalBase):
             </log>
         </merge>
     </log>
-</logs>''' % bzrlib.user_encoding)
+</logs>''' % bzrlib.osutils.get_user_encoding())
         return xml
 
     def test_nested_merges(self):
@@ -482,11 +483,15 @@ class TestLogEncodings(TestCaseInTempDir):
 
     def setUp(self):
         TestCaseInTempDir.setUp(self)
-        self.user_encoding = osutils._cached_user_encoding
+        self.old_user_encoding = osutils._cached_user_encoding
+        self.old_get_user_encoding = osutils.get_user_encoding
 
     def tearDown(self):
-        osutils._cached_user_encoding = self.user_encoding
-        bzrlib.user_encoding = self.user_encoding
+        osutils._cached_user_encoding = self.old_user_encoding
+        if hasattr(bzrlib, 'user_encoding'):
+            bzrlib.user_encoding = self.old_user_encoding
+        osutils._cached_user_encoding = self.old_user_encoding
+        osutils.get_user_encoding = self.old_get_user_encoding
         TestCaseInTempDir.tearDown(self)
 
     def create_branch(self):
@@ -511,7 +516,9 @@ class TestLogEncodings(TestCaseInTempDir):
         # it to be used
         try:
             osutils._cached_user_encoding = 'ascii'
-            bzrlib.user_encoding  = 'ascii'
+            bzrlib.osutils.get_user_encoding = lambda: 'ascii'
+            if hasattr(bzrlib, 'user_encoding'):
+                bzrlib.user_encoding = 'ascii'
             # We should be able to handle any encoding
             out, err = bzr('xmllog', encoding=encoding)
             if not fail:
@@ -523,7 +530,8 @@ class TestLogEncodings(TestCaseInTempDir):
                 self.assertNotEqual(-1, out.find('Message with ?'))
         finally:
             osutils._cached_user_encoding = old_encoding
-            bzrlib.user_encoding = old_encoding
+            if hasattr(bzrlib, 'user_encoding'):
+                bzrlib.user_encoding = old_encoding
 
     def test_log_handles_encoding(self):
         self.create_branch()
@@ -539,8 +547,10 @@ class TestLogEncodings(TestCaseInTempDir):
 
     def test_stdout_encoding(self):
         bzr = self.run_bzr
-        osutils._cached_user_encoding = "cp1251"
-        bzrlib.user_encoding = "cp1251"
+        osutils._cached_user_encoding = 'cp1251'
+        bzrlib.osutils.get_user_encoding = lambda: 'cp1251'
+        if hasattr(bzrlib, 'user_encoding'):
+            bzrlib.user_encoding = 'cp1251'
 
         bzr('init')
         self.build_tree(['a'])
@@ -577,7 +587,7 @@ class TestLogFile(TestCaseWithTransport):
 
     def setUp(self):
         TestCaseWithTransport.setUp(self)
-    
+
     def prepare_tree(self, complex=False):
         # The complex configuration includes deletes and renames
         tree = self.make_branch_and_tree('parent')
